@@ -18,13 +18,6 @@ class DefaultSettings(object):
         """
         return settings.LOGIN_URL
 
-    @property
-    def SITE_URL(self):
-        """
-        OPTIONAL. The OP server url.
-        """
-        return None
-
     @property
     def ISSUER_URL(self):
         """
@@ -32,6 +25,13 @@ class DefaultSettings(object):
         """
         return None
 
+    @property
+    def ISSUER_URL_WITH_TRAILING_SLASH(self):
+        """
+        OPTIONAL. When undefined ISSUER_URL, whether or not issuer URL with trailing slash
+        """
+        return False
+
     @property
     def OIDC_AFTER_USERLOGIN_HOOK(self):
         """
